bayespy.inference.vmp.nodes.gaussian.GaussianGammaMoments.from_values
=====================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaMoments.from_values